@@ -129,6 +129,7 @@ class BaseAssembly:
         for i in range(len(possibles) - 1, -1, -1):
             if len(possibles[i].frags[0]) != longest_first_frag:
                 del possibles[i]
+                del possibles_info[i]
 
         longest_frag = 0
         for p in possibles:
@@ -156,22 +157,28 @@ class BaseAssembly:
             # Special, common case where we can override the addressing mode
             # The mode might be forced with "<" or ">"
             # If not, we might have the address defined. If so, pick based on value.
-            sz = 's2'
-            if '_default_base_page' in assembler.defines and assembler.defines['_default_base_page'] == 'true':
-                sz = 's1'
+            sz = 1
+            if '_default_base_page' in assembler.defines and assembler.defines['_default_base_page'] == 'false':
+                sz = 2
             if '>' in text:
-                sz = 's2'
+                sz = 2
             elif '<' in text:
-                sz = 's1'
-            for i in range(len(possibles)):
-                op = possibles[i]
-                for u in op.use:
-                    if sz in op.use[u]:
-                        return (op, possibles_info[i])
+                sz = 1
 
-        raise AssemblyException('Multiple Matches')
+            for i in range(len(possibles) - 1, -1, -1):
+                cnt = 0
+                for f in possibles[i].code:
+                    if isinstance(f, str):
+                        cnt += 1
+                if cnt == sz:
+                    # The Z80 includes repeats like 2A and ED6B. TODO: fix this
+                    return(possibles[i], possibles_info[i])
 
-    def fill_in_opcode(self, _text, asm, _address, op, pass_number):
+        return (possibles[0], possibles_info[0])
+
+        # raise AssemblyException('Multiple Matches')
+
+    def fill_in_opcode(self, _text, asm, address, op, pass_number):
         '''
         '''
 
@@ -187,11 +194,13 @@ class BaseAssembly:
             for c in opcode.code:
                 if isinstance(c, str):
                     numval = info[c[0]][1]
-                    # TODO: PCR
+                    if 'pcr' in opcode.use[key]:
+                        numval = numval - address - len(opcode.code)
                     if c[1] == '1':
                         ret.append((numval >> 8) & 0xFF)
                     else:
                         ret.append(numval & 0xFF)
+                    # TODO: we need to make sure these fit values fit their given size
                     # print('##',text,info,opcode.use)
                 else:
                     ret.append(c)
